js.dynatree
===========

Introduction
------------

This library packages `jquery.dynatree.js`_ for `fanstatic`_.

.. _`fanstatic`: http://fanstatic.org
.. _`jquery.dynatree.js`: https://code.google.com/p/dynatree/

This requires integration between your web framework and ``fanstatic``,
and making sure that the original resources (shipped in the ``resources``
directory in ``js.dynatree``) are published to some URL.

